"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _getLog = _interopRequireDefault(require("./js/get-log"));

var _beginTransaction = _interopRequireDefault(require("./js/begin-transaction"));

var _commitTransaction = _interopRequireDefault(require("./js/commit-transaction"));

var _rollbackTransaction = _interopRequireDefault(require("./js/rollback-transaction"));

var _constants = require("./js/constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const connect = async (pool, specific) => {
  var _pool$config;

  const log = (0, _getLog.default)('connect');
  log.debug('configuring RDS data service client');
  const {
    RDSDataService,
    escapeId,
    escape,
    fullJitter,
    executeStatement,
    coercer
  } = specific;
  const {
    dbClusterOrInstanceArn,
    awsSecretStoreArn,
    databaseName,
    eventsTableName = 'events',
    snapshotsTableName = 'snapshots',
    secretsTableName,
    bucketSize,
    ...rdsConfig
  } = (_pool$config = pool.config) !== null && _pool$config !== void 0 ? _pool$config : {};
  pool.bucketSize = bucketSize;

  if (!Number.isInteger(pool.bucketSize) || pool.bucketSize < 1) {
    pool.bucketSize = _constants.DEFAULT_BUCKET_SIZE;
  }

  const rdsDataService = new RDSDataService(rdsConfig);
  Object.assign(pool, {
    rdsDataService,
    dbClusterOrInstanceArn,
    awsSecretStoreArn,
    databaseName,
    eventsTableName,
    secretsTableName,
    snapshotsTableName,
    fullJitter,
    coercer,
    executeStatement: executeStatement.bind(null, pool),
    beginTransaction: _beginTransaction.default,
    commitTransaction: _commitTransaction.default,
    rollbackTransaction: _rollbackTransaction.default,
    escapeId,
    escape
  });
  log.debug('RDS data service client configured');
};

var _default = connect;
exports.default = _default;
//# sourceMappingURL=connect.js.map